==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/rt/frontend/jaxws/src/main/java/org/apache/cxf/jaxws/support/BindingID.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxws.support;

import javax.xml.ws.soap.SOAPBinding;

import org.apache.cxf.binding.soap.SoapBindingFactory;
import org.apache.cxf.binding.soap.SoapTransportFactory;

public final class BindingID {

    private BindingID() {
    }

    public static String getJaxwsBindingID(String transportID) {
        if (SoapTransportFactory.SOAP_11_HTTP_BINDING.equals(transportID)) {
            return SOAPBinding.SOAP11HTTP_BINDING;
        } else if (SoapTransportFactory.SOAP_12_HTTP_BINDING.equals(transportID)) {
            return SOAPBinding.SOAP12HTTP_BINDING;
        } else {
            return transportID;
        }
    }

    public static String getBindingID(String jaxwsBindingID) {
        if (SOAPBinding.SOAP11HTTP_BINDING.equals(jaxwsBindingID)
                || SOAPBinding.SOAP11HTTP_MTOM_BINDING.equals(jaxwsBindingID)) {
            return SoapBindingFactory.SOAP_11_BINDING;
        } else if (SOAPBinding.SOAP12HTTP_BINDING.equals(jaxwsBindingID)
                || SOAPBinding.SOAP12HTTP_MTOM_BINDING.equals(jaxwsBindingID)) {
            return SoapBindingFactory.SOAP_12_BINDING;
        } else {
            return jaxwsBindingID;
        }
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/rt/frontend/jaxws/src/main/java/org/apache/cxf/jaxws/support/BindingID.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxws.support;

import jakarta.xml.ws.soap.SOAPBinding;
import org.apache.cxf.binding.soap.SoapBindingFactory;
import org.apache.cxf.binding.soap.SoapTransportFactory;

public final class BindingID {

    private BindingID() {
    }

    public static String getJaxwsBindingID(String transportID) {
        if (SoapTransportFactory.SOAP_11_HTTP_BINDING.equals(transportID)) {
            return SOAPBinding.SOAP11HTTP_BINDING;
        } else if (SoapTransportFactory.SOAP_12_HTTP_BINDING.equals(transportID)) {
            return SOAPBinding.SOAP12HTTP_BINDING;
        } else {
            return transportID;
        }
    }

    public static String getBindingID(String jaxwsBindingID) {
        if (SOAPBinding.SOAP11HTTP_BINDING.equals(jaxwsBindingID)
                || SOAPBinding.SOAP11HTTP_MTOM_BINDING.equals(jaxwsBindingID)) {
            return SoapBindingFactory.SOAP_11_BINDING;
        } else if (SOAPBinding.SOAP12HTTP_BINDING.equals(jaxwsBindingID)
                || SOAPBinding.SOAP12HTTP_MTOM_BINDING.equals(jaxwsBindingID)) {
            return SoapBindingFactory.SOAP_12_BINDING;
        } else {
            return jaxwsBindingID;
        }
    }

}
